@@ -49,8 +49,6 @@
 #define BACKUP_DIRECTORY "/var/lib/nvidia"
 #define BACKUP_LOG       (BACKUP_DIRECTORY "/log")
 
-#define RMMOD_MODULE_NAME "nvidia"
-
 /*
  * XXX when uninstalling should we remove directories that were
  * created by our installation?
@@ -119,6 +117,7 @@ typedef struct {
 } BackupInfo;
 
 
+
 static BackupInfo *read_backup_log_file(Options *op);
 
 static void free_backup_info(BackupInfo *b);
@@ -501,7 +500,7 @@ static int do_uninstall(Options *op)
     BackupLogEntry *e;
     BackupInfo *b;
     int i, len, ok;
-    char *tmpstr, *cmd;
+    char *tmpstr;
     float percent;
 
     static const char existing_installation_is_borked[] = 
@@ -659,15 +658,6 @@ static int do_uninstall(Options *op)
         /* XXX what to do if this fails?... nothing */
     }
 
-    /*
-     * attempt to unload the kernel module, but don't abort if this fails: the
-     * kernel may not have been configured with support for module unloading
-     * (Linux 2.6) or the user might have unloaded it themselves.
-     */
-    cmd = nvstrcat(op->utils[RMMOD], " ", RMMOD_MODULE_NAME, NULL);
-    run_command(op, cmd, NULL, FALSE, 0, TRUE);
-    nvfree(cmd);
-
     run_distro_hook(op, "post-uninstall");
 
     free_backup_info(b);
