@@ -233,8 +233,7 @@ CommandList *build_command_list(Options *op, Package *p)
          */
         if (op->selinux_enabled &&
             (op->utils[EXECSTACK] != NULL) &&
-            ((p->entries[i].flags & FILE_TYPE_SHARED_LIB) ||
-             (p->entries[i].flags & FILE_TYPE_XMODULE_SHARED_LIB))) {
+            (p->entries[i].flags & FILE_TYPE_SHARED_LIB)) {
             tmp = nvstrcat(op->utils[EXECSTACK], " -c ",
                            p->entries[i].dst, NULL);
         } else {
@@ -263,8 +262,7 @@ CommandList *build_command_list(Options *op, Package *p)
         }
 
         if (op->selinux_enabled &&
-            ((p->entries[i].flags & FILE_TYPE_SHARED_LIB) ||
-             (p->entries[i].flags & FILE_TYPE_XMODULE_SHARED_LIB))) {
+            (p->entries[i].flags & FILE_TYPE_SHARED_LIB)) {
             tmp = nvstrcat(op->utils[CHCON], " -t ", op->selinux_chcon_type,
                            " ", p->entries[i].dst, NULL);
             add_command(c, RUN_CMD, tmp);
@@ -489,8 +487,9 @@ int execute_command_list(Options *op, CommandList *c,
             ui_status_update(op, percent, "Creating symlink: %s",
                              c->cmds[i].s1);
 
-            ret = symlink(c->cmds[i].s1, c->cmds[i].s0);
-            if (ret == -1) {
+            ret = install_symlink(op, c->cmds[i].s1, c->cmds[i].s0);
+
+            if (!ret) {
                 ret = continue_after_error(op, "Cannot create symlink %s (%s)",
                                            c->cmds[i].s0, strerror(errno));
                 if (!ret) return FALSE;
@@ -566,19 +565,19 @@ static void find_conflicting_libraries(Options *op,
                                        FileList *l);
 
 static ConflictingFileInfo __xfree86_libs[] = {
-    { "libGLcore.",       10, /* strlen("libGLcore.") */       NULL            },
-    { "libGL.",           6,  /* strlen("libGL.") */           NULL            },
-    { "libGLwrapper.",    13, /* strlen("libGLwrapper.") */    NULL            },
-    { "libglx.",          7,  /* strlen("libglx.") */          "glxModuleData" },
-    { "libglamoregl.",       13, /* strlen("libglamoregl.") */ NULL            },
-    { "libXvMCNVIDIA",    13, /* strlen("libXvMCNVIDIA") */    NULL            },
-    { "libnvidia-cfg.",   14, /* strlen("libnvidia-cfg.") */   NULL            },
-    { "nvidia_drv.",      11, /* strlen("nvidia_drv.") */      NULL            },
-    { "libcuda.",         8,  /* strlen("libcuda.") */         NULL            },
-    { "libvdpau.",        9,  /* strlen("libvdpau.") */        NULL            },
-    { "libvdpau_trace.",  15, /* strlen("libvdpau_trace.") */  NULL            },
-    { "libvdpau_nvidia.", 16, /* strlen("libvdpau_nvidia.") */ NULL            },
-    { NULL,               0,                                   NULL            }
+    { "libGLcore.",          10, /* strlen("libGLcore.") */          NULL            },
+    { "libGL.",              6,  /* strlen("libGL.") */              NULL            },
+    { "libGLwrapper.",       13, /* strlen("libGLwrapper.") */       NULL            },
+    { "libglx.",             7,  /* strlen("libglx.") */             "glxModuleData" },
+    { "libXvMCNVIDIA",       13, /* strlen("libXvMCNVIDIA") */       NULL            },
+    { "libnvidia-cfg.",      14, /* strlen("libnvidia-cfg.") */      NULL            },
+    { "nvidia_drv.",         11, /* strlen("nvidia_drv.") */         NULL            },
+    { "libcuda.",            8,  /* strlen("libcuda.") */            NULL            },
+    { "libvdpau.",           9,  /* strlen("libvdpau.") */           NULL            },
+    { "libvdpau_trace.",     15, /* strlen("libvdpau_trace.") */     NULL            },
+    { "libvdpau_nvidia.",    16, /* strlen("libvdpau_nvidia.") */    NULL            },
+    { "libnvidia-compiler.", 19, /* strlen("libnvidia-compiler.") */ NULL            },
+    { NULL,                  0,                                      NULL            }
 };
 
 /*
@@ -616,13 +615,14 @@ static void find_conflicting_xfree86_libraries_fullpath(Options *op,
 
 
 static ConflictingFileInfo __opengl_libs[] = {
-    { "libGLcore.",     10, /* strlen("libGLcore.") */     NULL },
-    { "libGL.",         6,  /* strlen("libGL.") */         NULL },
-    { "libnvidia-tls.", 14, /* strlen("libnvidia-tls.") */ NULL },
-    { "libGLwrapper.",  13, /* strlen("libGLwrapper.") */  NULL },
-    { "libnvidia-cfg.", 14, /* strlen("libnvidia-cfg.") */ NULL },
-    { "libcuda.",       8,  /* strlen("libcuda.") */       NULL },
-    { NULL,             0,                                 NULL }
+    { "libGLcore.",          10, /* strlen("libGLcore.") */          NULL },
+    { "libGL.",              6,  /* strlen("libGL.") */              NULL },
+    { "libnvidia-tls.",      14, /* strlen("libnvidia-tls.") */      NULL },
+    { "libGLwrapper.",       13, /* strlen("libGLwrapper.") */       NULL },
+    { "libnvidia-cfg.",      14, /* strlen("libnvidia-cfg.") */      NULL },
+    { "libcuda.",            8,  /* strlen("libcuda.") */            NULL },
+    { "libnvidia-compiler.", 19, /* strlen("libnvidia-compiler.") */ NULL },
+    { NULL,                  0,                                      NULL }
 };
 
 /*
@@ -654,6 +654,7 @@ static void find_conflicting_kernel_modules(Options *op,
     char *paths[3];
     char *tmp = get_kernel_name(op);
 
+    memset(files, 0, sizeof(files));
     files[1].name = NULL;
     files[1].len = 0;
     paths[0] = op->kernel_module_installation_path;
