@@ -513,6 +513,18 @@ int set_destinations(Options *op, Package *p)
             path = "";
             break;
 
+        case FILE_TYPE_VDPAU_LIB:
+        case FILE_TYPE_VDPAU_SYMLINK:
+            if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
+                prefix = op->compat32_prefix;
+                dir = op->compat32_libdir;
+            } else {
+                prefix = op->opengl_prefix;
+                dir = op->opengl_libdir;
+            }
+            path = p->entries[i].path;
+            break;
+
         case FILE_TYPE_CUDA_LIB:
         case FILE_TYPE_CUDA_SYMLINK:
             if (p->entries[i].flags & FILE_CLASS_COMPAT32) {
@@ -522,8 +534,14 @@ int set_destinations(Options *op, Package *p)
                 prefix = op->opengl_prefix;
                 dir = op->opengl_libdir;
             }
-            path = "";
+            path = p->entries[i].path;
             break;
+
+        case FILE_TYPE_CUDA_ICD:
+            prefix = DEFAULT_CUDA_ICD_PREFIX;
+            dir = DEFAULT_CUDA_ICD_DIR;
+            path = "";
+            break;            
             
         case FILE_TYPE_XLIB_SHARED_LIB:
         case FILE_TYPE_XLIB_STATIC_LIB:
@@ -579,6 +597,7 @@ int set_destinations(Options *op, Package *p)
 
         case FILE_TYPE_OPENGL_HEADER:
         case FILE_TYPE_CUDA_HEADER:
+        case FILE_TYPE_VDPAU_HEADER:
             prefix = op->opengl_prefix;
             dir = op->opengl_incdir;
             path = p->entries[i].path;
@@ -1176,6 +1195,36 @@ int install_file(Options *op, const char *srcfile,
 } /* install_file() */
 
 
+/*
+ * install_symlink() - install dstfile as a symlink to linkname; this
+ * is done by extracting the directory portion of dstfile, creating
+ * that directory if it does not exist, and then calling symlink().
+ */ 
+
+int install_symlink(Options *op, const char *linkname, const char *dstfile)
+{   
+    int retval; 
+    char *dirc, *dname;
+
+    dirc = nvstrdup(dstfile);
+    dname = dirname(dirc);
+    
+    if (!mkdir_recursive(op, dname, 0755)) {
+        free(dirc);
+        return FALSE;
+    }
+
+    if (symlink(linkname, dstfile)) {
+        free(dirc);
+        return FALSE;
+    }
+
+    free(dirc);
+    return TRUE;
+
+} /* install_symlink() */
+
+
 
 size_t get_file_size(Options *op, const char *filename)
 {
