@@ -38,4 +38,8 @@ void fmterr(const char *fmt, ...);
 void fmterrp(const char *prefix, const char *fmt, ...);
 void format(FILE *stream, const char *prefix, const char *fmt, ...);
 
+TextRows *nv_format_text_rows(const char *prefix, const char *buf,
+                              int width, int word_boundary);
+void nv_free_text_rows(TextRows *t);
+
 #endif /* __NVIDIA_INSTALLER_FORMAT_H__ */
