@@ -139,10 +139,6 @@ int install_from_cwd(Options *op)
     }
     ran_pre_install_hook = TRUE;
 
-    /* fail if the nouveau driver is currently in use */
-
-    if (!check_for_nouveau(op)) goto failed;
-
     /* attempt to build a kernel module for the target kernel */
 
     if (!op->no_kernel_module) {
@@ -681,6 +677,8 @@ static Package *parse_manifest (Options *op)
                 p->entries[n].flags |= FILE_TYPE_OPENGL_HEADER;
             else if (strcmp(flag, "CUDA_HEADER") == 0)
                 p->entries[n].flags |= FILE_TYPE_CUDA_HEADER;
+            else if (strcmp(flag, "CUDA_ICD") == 0)
+                p->entries[n].flags |= FILE_TYPE_CUDA_ICD;
             else if (strcmp(flag, "OPENGL_LIB") == 0)
                 p->entries[n].flags |= FILE_TYPE_OPENGL_LIB;
             else if (strcmp(flag, "CUDA_LIB") == 0)
@@ -723,6 +721,12 @@ static Package *parse_manifest (Options *op)
                 p->entries[n].flags |= FILE_TYPE_XMODULE_SYMLINK;
             else if (strcmp(flag, "XMODULE_NEWSYM") == 0)
                 p->entries[n].flags |= FILE_TYPE_XMODULE_NEWSYM;
+            else if (strcmp(flag, "VDPAU_HEADER") == 0)
+                p->entries[n].flags |= FILE_TYPE_VDPAU_HEADER;
+            else if (strcmp(flag, "VDPAU_LIB") == 0)
+                p->entries[n].flags |= FILE_TYPE_VDPAU_LIB;
+            else if (strcmp(flag, "VDPAU_SYMLINK") == 0)
+                p->entries[n].flags |= FILE_TYPE_VDPAU_SYMLINK;
             else {
                 nvfree(flag);
                 goto invalid_manifest_file;
