@@ -79,7 +79,6 @@ static FILE *log_file_stream;
 void log_init(Options *op)
 {
     time_t now;
-    char *path;
 
     if (!op->logging) return;
     
@@ -101,128 +100,108 @@ void log_init(Options *op)
     log_printf(op, TRUE, NULL, "installer version: %s",
                NVIDIA_INSTALLER_VERSION);
     log_printf(op, TRUE, NULL, "");
-
-    path = getenv("PATH");
-    log_printf(op, TRUE, NULL, "PATH: %s", STRSTR(path));
-    log_printf(op, TRUE, NULL, "");
-
+    
     log_printf(op, TRUE, NULL, "option status:");
-    log_printf(op, TRUE, NULL, "  license pre-accepted               : %s",
+    log_printf(op, TRUE, NULL, "  license pre-accepted    : %s",
                BOOLSTR(op->accept_license));
-    log_printf(op, TRUE, NULL, "  update                             : %s",
+    log_printf(op, TRUE, NULL, "  update                  : %s",
                BOOLSTR(op->update));
-    log_printf(op, TRUE, NULL, "  force update                       : %s",
+    log_printf(op, TRUE, NULL, "  force update            : %s",
                BOOLSTR(op->force_update));
-    log_printf(op, TRUE, NULL, "  expert                             : %s",
+    log_printf(op, TRUE, NULL, "  expert                  : %s",
                BOOLSTR(op->expert));
-    log_printf(op, TRUE, NULL, "  uninstall                          : %s",
+    log_printf(op, TRUE, NULL, "  uninstall               : %s",
                BOOLSTR(op->uninstall));
-    log_printf(op, TRUE, NULL, "  driver info                        : %s",
+    log_printf(op, TRUE, NULL, "  driver info             : %s",
                BOOLSTR(op->driver_info));
-    log_printf(op, TRUE, NULL, "  precompiled interfaces             : %s",
+    log_printf(op, TRUE, NULL, "  precompiled interfaces  : %s",
                BOOLSTR(!op->no_precompiled_interface));
-    log_printf(op, TRUE, NULL, "  no ncurses color                   : %s",
+    log_printf(op, TRUE, NULL, "  no ncurses color        : %s",
                BOOLSTR(op->no_ncurses_color));
-    log_printf(op, TRUE, NULL, "  query latest version               : %s",
+    log_printf(op, TRUE, NULL, "  query latest version    : %s",
                BOOLSTR(op->latest));
-    log_printf(op, TRUE, NULL, "  OpenGL header files                : %s",
+    log_printf(op, TRUE, NULL, "  OpenGL header files     : %s",
                BOOLSTR(op->opengl_headers));
-    log_printf(op, TRUE, NULL, "  no questions                       : %s",
+    log_printf(op, TRUE, NULL, "  no questions            : %s",
                BOOLSTR(op->no_questions));
-    log_printf(op, TRUE, NULL, "  silent                             : %s",
+    log_printf(op, TRUE, NULL, "  silent                  : %s",
                BOOLSTR(op->silent));
-    log_printf(op, TRUE, NULL, "  no recursion                       : %s",
+    log_printf(op, TRUE, NULL, "  no recursion            : %s",
                BOOLSTR(op->no_recursion));
-    log_printf(op, TRUE, NULL, "  no backup                          : %s",
+    log_printf(op, TRUE, NULL, "  no backup               : %s",
                BOOLSTR(op->no_backup));
-    log_printf(op, TRUE, NULL, "  kernel module only                 : %s",
+    log_printf(op, TRUE, NULL, "  kernel module only      : %s",
                BOOLSTR(op->kernel_module_only));
-    log_printf(op, TRUE, NULL, "  sanity                             : %s",
+    log_printf(op, TRUE, NULL, "  sanity                  : %s",
                BOOLSTR(op->sanity));
-    log_printf(op, TRUE, NULL, "  add this kernel                    : %s",
+    log_printf(op, TRUE, NULL, "  add this kernel         : %s",
                BOOLSTR(op->add_this_kernel));
-    log_printf(op, TRUE, NULL, "  no runlevel check                  : %s",
+    log_printf(op, TRUE, NULL, "  no runlevel check       : %s",
                BOOLSTR(op->no_runlevel_check));
-    log_printf(op, TRUE, NULL, "  no network                         : %s",
+    log_printf(op, TRUE, NULL, "  no network              : %s",
                BOOLSTR(op->no_network));
-    log_printf(op, TRUE, NULL, "  no ABI note                        : %s",
+    log_printf(op, TRUE, NULL, "  no ABI note             : %s",
                BOOLSTR(op->no_abi_note));
-    log_printf(op, TRUE, NULL, "  no RPMs                            : %s",
+    log_printf(op, TRUE, NULL, "  no RPMs                 : %s",
                BOOLSTR(op->no_rpms));
-    log_printf(op, TRUE, NULL, "  no kernel module                   : %s",
+    log_printf(op, TRUE, NULL, "  no kernel module        : %s",
                BOOLSTR(op->no_kernel_module));
-    log_printf(op, TRUE, NULL, "  force SELinux                      : %s",
+    log_printf(op, TRUE, NULL, "  force SELinux           : %s",
                SELINUXSTR(op->selinux_option));
-    log_printf(op, TRUE, NULL, "  no X server check                  : %s",
+    log_printf(op, TRUE, NULL, "  no X server check       : %s",
                BOOLSTR(op->no_x_check));
-    log_printf(op, TRUE, NULL, "  no cc version check                : %s",
+    log_printf(op, TRUE, NULL, "  no cc version check     : %s",
                BOOLSTR(op->ignore_cc_version_check));
-    log_printf(op, TRUE, NULL, "  run distro scripts                 : %s",
-               BOOLSTR(op->run_distro_scripts));
-    log_printf(op, TRUE, NULL, "  no nouveau check                   : %s",
-               BOOLSTR(op->no_nouveau_check));
-    log_printf(op, TRUE, NULL, "  run nvidia-xconfig                 : %s",
-               BOOLSTR(op->run_nvidia_xconfig));
-    log_printf(op, TRUE, NULL, "  sigwinch work around               : %s",
-               BOOLSTR(op->sigwinch_workaround));
-    log_printf(op, TRUE, NULL, "  force tls                          : %s",
+    log_printf(op, TRUE, NULL, "  force tls               : %s",
                TLSSTR(op->which_tls));
 #if defined(NV_X86_64)
-    log_printf(op, TRUE, NULL, "  force compat32 tls                 : %s",
+    log_printf(op, TRUE, NULL, "  force compat32 tls      : %s",
                TLSSTR(op->which_tls_compat32));
 #endif
-    log_printf(op, TRUE, NULL, "  X install prefix                   : %s",
+    log_printf(op, TRUE, NULL, "  X install prefix        : %s",
                STRSTR(op->x_prefix));
-    log_printf(op, TRUE, NULL, "  X library install path             : %s",
+    log_printf(op, TRUE, NULL, "  X library install path  : %s",
                STRSTR(op->x_library_path));
-    log_printf(op, TRUE, NULL, "  X module install path              : %s",
+    log_printf(op, TRUE, NULL, "  X module install path   : %s",
                STRSTR(op->x_module_path));
-    log_printf(op, TRUE, NULL, "  OpenGL install prefix              : %s",
+    log_printf(op, TRUE, NULL, "  OpenGL install prefix   : %s",
                STRSTR(op->opengl_prefix));
-    log_printf(op, TRUE, NULL, "  OpenGL install libdir              : %s",
+    log_printf(op, TRUE, NULL, "  OpenGL install libdir   : %s",
                STRSTR(op->opengl_libdir));
 #if defined(NV_X86_64)
-    log_printf(op, TRUE, NULL, "  compat32 install chroot            : %s",
+    log_printf(op, TRUE, NULL, "  compat32 install chroot : %s",
                STRSTR(op->compat32_chroot));
-    log_printf(op, TRUE, NULL, "  compat32 install prefix            : %s",
+    log_printf(op, TRUE, NULL, "  compat32 install prefix : %s",
                STRSTR(op->compat32_prefix));
-    log_printf(op, TRUE, NULL, "  compat32 install libdir            : %s",
+    log_printf(op, TRUE, NULL, "  compat32 install libdir : %s",
                STRSTR(op->compat32_libdir));
 #endif
-    log_printf(op, TRUE, NULL, "  utility install prefix             : %s",
+    log_printf(op, TRUE, NULL, "  utility install prefix  : %s",
                STRSTR(op->utility_prefix));
-    log_printf(op, TRUE, NULL, "  utility install libdir             : %s",
+    log_printf(op, TRUE, NULL, "  utility install libdir  : %s",
                STRSTR(op->utility_libdir));
-    log_printf(op, TRUE, NULL, "  installer prefix                   : %s",
-               STRSTR(op->installer_prefix));
-    log_printf(op, TRUE, NULL, "  doc install prefix                 : %s",
+    log_printf(op, TRUE, NULL, "  doc install prefix      : %s",
                STRSTR(op->documentation_prefix));
-    log_printf(op, TRUE, NULL, "  kernel name                        : %s",
+    log_printf(op, TRUE, NULL, "  kernel name             : %s",
                STRSTR(op->kernel_name));
-    log_printf(op, TRUE, NULL, "  kernel include path                : %s",
+    log_printf(op, TRUE, NULL, "  kernel include path     : %s",
                STRSTR(op->kernel_include_path));
-    log_printf(op, TRUE, NULL, "  kernel source path                 : %s",
+    log_printf(op, TRUE, NULL, "  kernel source path      : %s",
                STRSTR(op->kernel_source_path));
-    log_printf(op, TRUE, NULL, "  kernel output path                 : %s",
+    log_printf(op, TRUE, NULL, "  kernel output path      : %s",
                STRSTR(op->kernel_output_path));
-    log_printf(op, TRUE, NULL, "  kernel install path                : %s",
+    log_printf(op, TRUE, NULL, "  kernel install path     : %s",
                STRSTR(op->kernel_module_installation_path));
-    log_printf(op, TRUE, NULL, "  precompiled kernel interfaces path : %s",
-               STRSTR(op->precompiled_kernel_interfaces_path));
-    log_printf(op, TRUE, NULL, "  precompiled kernel interfaces url  : %s",
-               STRSTR(op->precompiled_kernel_interfaces_url));
-    log_printf(op, TRUE, NULL, "  proc mount point                   : %s",
+    log_printf(op, TRUE, NULL, "  proc mount point        : %s",
                STRSTR(op->proc_mount_point));
-    log_printf(op, TRUE, NULL, "  ui                                 : %s",
+    log_printf(op, TRUE, NULL, "  ui                      : %s",
                STRSTR(op->ui_str));
-    log_printf(op, TRUE, NULL, "  tmpdir                             : %s",
+    log_printf(op, TRUE, NULL, "  tmpdir                  : %s",
                STRSTR(op->tmpdir));
-    log_printf(op, TRUE, NULL, "  ftp mirror                         : %s",
+    log_printf(op, TRUE, NULL, "  ftp mirror              : %s",
                STRSTR(op->ftp_site));
-    log_printf(op, TRUE, NULL, "  RPM file list                      : %s",
+    log_printf(op, TRUE, NULL, "  RPM file list           : %s",
                STRSTR(op->rpm_file_list));
-    log_printf(op, TRUE, NULL, "  selinux chcon type                 : %s",
-               STRSTR(op->selinux_chcon_type));
 
 
     log_printf(op, TRUE, NULL, "");
@@ -232,7 +211,7 @@ void log_init(Options *op)
 
 
 /*
- * log_printf() - if the logging option is set, this function writes
+ * log_printf() - if the logggin option is set, this function writes
  * the given printf-style input to the log_file_stream; if the logging
  * option is not set, then nothing is done here.
  */
