@@ -58,149 +58,6 @@ static int check_symlink(Options*, const char*, const char*, const char*);
 static int check_file(Options*, const char*, const mode_t, const uint32);
 
 
-/*
- * nvalloc() - malloc wrapper that checks for errors, and zeros out
- * the memory; if an error occurs, an error is printed to stderr and
- * exit is called -- this function will only return on success.
- */
-
-void *nvalloc(size_t size)
-{
-    void *m = malloc(size);
-    
-    if (!m) {
-        fprintf(stderr, "%s: memory allocation failure (%s)! \n",
-                PROGRAM_NAME, strerror(errno));
-        exit(1);
-    }
-    memset((char *) m, 0, size);
-    return m;
-    
-} /* nvalloc() */
-
-
-
-/*
- * nvrealloc() - realloc wrapper that checks for errors; if an error
- * occurs, an error is printed to stderr and exit is called -- this
- * function will only return on success.
- */
-
-void *nvrealloc(void *ptr, size_t size)
-{
-    void *m;
-
-    if (ptr == NULL) return nvalloc(size);
-    
-    m = realloc(ptr, size);
-    if (!m) {
-        fprintf(stderr, "%s: memory re-allocation failure (%s)! \n",
-                PROGRAM_NAME, strerror(errno));
-        exit(1);
-    }
-    return m;
-
-} /* nvrealloc() */
-
-
-
-/*
- * nvstrdup() - wrapper for strdup() that checks the return value; if
- * an error occurs, an error is printed to stderr and exit is called
- * -- this function will only return on success.
- */
-
-char *nvstrdup(const char *s)
-{
-    char *m;
-
-    if (!s) return NULL;
-
-    m = strdup(s);
-    
-    if (!m) {
-        fprintf(stderr, "%s: memory allocation failure during strdup (%s)! \n",
-                PROGRAM_NAME, strerror(errno));
-        exit(1);
-    }
-    return m;
-    
-} /* nvstrdup() */
-
-
-
-/*
- * nvfree() - 
- */
-void nvfree(char *s)
-{
-    if (s) free(s);
-
-} /* nvfree() */
-
-
-
-/*
- * nvstrtolower() - convert the given string to lowercase.
- */
-
-char *nvstrtolower(char *s)
-{
-    char *start = s;
-
-    if (s == NULL) return NULL;
-
-    while (*s) {
-        *s = tolower(*s);
-        s++;
-    }
-
-    return start;
-
-} /* nvstrtolower() */
-
-
-
-/*
- * nvstrcat() - allocate a new string, copying all given strings
- * into it.  taken from glib
- */
-
-char *nvstrcat(const char *str, ...)
-{
-    unsigned int l;
-    va_list args;
-    char *s;
-    char *concat;
-  
-    l = 1 + strlen(str);
-    va_start(args, str);
-    s = va_arg(args, char *);
-
-    while (s) {
-        l += strlen(s);
-        s = va_arg(args, char *);
-    }
-    va_end(args);
-  
-    concat = nvalloc(l);
-    concat[0] = 0;
-  
-    strcat(concat, str);
-    va_start(args, str);
-    s = va_arg(args, char *);
-    while (s) {
-        strcat(concat, s);
-        s = va_arg(args, char *);
-    }
-    va_end(args);
-  
-    return concat;
-
-} /* nvstrcat() */
-
-
-
 /*
  * read_next_word() - given a string buf, skip any whitespace, and
  * then copy the next set of characters until more white space is
@@ -1870,7 +1727,8 @@ static int rtld_test_internal(Options *op, Package *p,
         if (!name) continue;
 
         s = strstr(name, ".so.1");
-        if (!s || s[strlen(".so.1")] != '\0') goto next;
+        if (!s) goto next;
+        *(s + strlen(".so.1")) = '\0';
 
         cmd = nvstrcat(op->utils[LDD], " ", tmpfile, " > ", tmpfile1, NULL);
 
@@ -2552,369 +2410,3 @@ done:
     nvfree(cmd);
     return ret;
 }
-
-
-
-/*
- * Determine if the nouveau driver is currently in use.  We do the
- * equivalent of:
- *
- *   ls -l /sys/bus/pci/devices/ /driver | grep nouveau
- *
- * The directory structure under /sys/bus/pci/devices/ should contain
- * a directory for each PCI device, and for those devices with a
- * kernel driver there will be a "driver" symlink.
- *
- * This appears to be consistent with how libpciaccess works.
- *
- * Returns TRUE if nouveau is found; returns FALSE if not.
- */
-
-#define SYSFS_DEVICES_PATH "/sys/bus/pci/devices"
-
-static int nouveau_is_present(void)
-{
-    DIR *dir;
-    struct dirent * ent;
-    int found = FALSE;
-
-    dir = opendir(SYSFS_DEVICES_PATH);
-
-    if (!dir) {
-        return FALSE;
-    }
-
-    while ((ent = readdir(dir)) != NULL) {
-
-        char driver_path[PATH_MAX];
-        char symlink_target[PATH_MAX];
-        char *name;
-        ssize_t ret;
-
-        if ((strcmp(ent->d_name, ".") == 0) ||
-            (strcmp(ent->d_name, "..") == 0)) {
-            continue;
-        }
-
-        snprintf(driver_path, PATH_MAX,
-                 SYSFS_DEVICES_PATH "/%s/driver", ent->d_name);
-
-        driver_path[PATH_MAX - 1] = '\0';
-
-        ret = readlink(driver_path, symlink_target, PATH_MAX);
-        if (ret < 0) {
-            continue;
-        }
-
-        /* readlink(3) does not nul-terminate its returned string */
-
-        ret = NV_MIN(ret, PATH_MAX - 1);
-
-        symlink_target[ret] = '\0';
-
-        name = basename(symlink_target);
-
-        if (strcmp(name, "nouveau") == 0) {
-            found = TRUE;
-            break;
-        }
-    }
-
-    closedir(dir);
-
-    return found;
-}
-
-
-
-/*
- * Write a modprobe configuration fragment to disable loading of
- * nouveau:
- *
- *  if [ -d /etc/modprobe.d ]; then
- *      name=/etc/modprobe.d/nvidia-installer-nouveau-blacklist
- *      echo "# generated by nvidia-installer" > $name
- *      echo "blacklist nouveau" >> $name
- *      echo "options nouveau modeset=0" >> $name
- *  fi
- *
- * Returns TRUE if successful; returns FALSE if there was a failure.
- */
-
-#define ETC_MODPROBE_D "/etc/modprobe.d"
-#define ETC_MODPROBE_D_FILE \
-  ETC_MODPROBE_D "/nvidia-installer-disable-nouveau.conf"
-
-/*
- * this checksum is the result of compute_crc() for the file contents
- * written in blacklist_nouveau()
- */
-
-#define ETC_MODPROBE_D_FILE_CKSUM 3728279991U
-
-static int blacklist_nouveau(void)
-{
-    int ret;
-    struct stat stat_buf;
-    FILE *file;
-
-    ret = stat(ETC_MODPROBE_D, &stat_buf);
-
-    if (ret != 0) {
-        return FALSE;
-    }
-
-    file = fopen(ETC_MODPROBE_D_FILE, "w+");
-
-    if (!file) {
-        return FALSE;
-    }
-
-    fprintf(file, "# generated by nvidia-installer\n");
-    fprintf(file, "blacklist nouveau\n");
-    fprintf(file, "options nouveau modeset=0\n");
-
-    ret = fclose(file);
-
-    if (ret != 0) {
-        return FALSE;
-    }
-
-    return TRUE;
-}
-
-
-
-/*
- * Check if the nouveau blacklist file is already present with the
- * contents that we expect
- */
-
-static int nouveau_blacklist_file_is_present(Options *op)
-{
-    if (access(ETC_MODPROBE_D_FILE, R_OK) != 0) {
-        return FALSE;
-    }
-
-    if (compute_crc(op, ETC_MODPROBE_D_FILE) != ETC_MODPROBE_D_FILE_CKSUM) {
-        return FALSE;
-    }
-
-    return TRUE;
-}
-
-
-
-/*
- * Check if the nouveau kernel driver is in use.  If it is, provide an
- * appropriate error message and offer to try to disable nouveau.
- *
- * Returns FALSE if the nouveau kernel driver is in use (cause
- * installation to abort); returns TRUE if the nouveau driver is not
- * in use.
- */
-
-int check_for_nouveau(Options *op)
-{
-    int ret;
-
-#define NOUVEAU_POINTER_MESSAGE                                         \
-    "Please consult the NVIDIA driver README and your Linux "           \
-        "distribution's documentation for details on how to correctly " \
-        "disable the Nouveau kernel driver."
-
-    if (op->no_nouveau_check) return TRUE;
-
-    if (!nouveau_is_present()) return TRUE;
-
-    ui_error(op, "The Nouveau kernel driver is currently in use "
-             "by your system.  This driver is incompatible with the NVIDIA "
-             "driver, and must be disabled before proceeding.  "
-             NOUVEAU_POINTER_MESSAGE);
-
-    if (nouveau_blacklist_file_is_present(op)) {
-        ui_warn(op, "The modprobe configuration file to disable Nouveau, "
-                ETC_MODPROBE_D_FILE ", is already present.  Please be "
-                "sure you have rebooted your system since that file was "
-                "written.  If you have rebooted, then Nouveau may be enabled "
-                "for other reasons, such as being included in the system "
-                "initial ramdisk or in your X configuration file.  "
-                NOUVEAU_POINTER_MESSAGE);
-        return FALSE;
-    }
-
-    ret = ui_yes_no(op, FALSE, "For some distributions, Nouveau can be "
-                    "disabled by adding a file in the modprobe configuration "
-                    "directory.  Would you like nvidia-installer to attempt "
-                    "to create this modprobe file for you?");
-
-    if (ret) {
-        ret = blacklist_nouveau();
-
-        if (ret) {
-            ui_message(op, "The modprobe configuration file to disable "
-                       "Nouveau, " ETC_MODPROBE_D_FILE ", has been written.  "
-                       "For some distributions, this may be sufficient to "
-                       "disable Nouveau; other distributions may require "
-                       "modification of the initial ramdisk.  Please reboot "
-                       "your system and attempt NVIDIA driver installation "
-                       "again.  Note if you later wish to reenable Nouveau, "
-                       "you will need to delete the file " 
-                       ETC_MODPROBE_D_FILE ".");
-        } else {
-            ui_warn(op, "Unable to alter the nouveau modprobe configuration.  "
-                    NOUVEAU_POINTER_MESSAGE);
-        }
-    }
-
-    return FALSE;
-}
-
-
-
-/*
- * nv_format_text_rows() - this function breaks the given string str
- * into some number of rows, where each row is not longer than the
- * specified width.
- *
- * If prefix is non-NULL, the first line is prepended with the prefix,
- * and subsequent lines are indented to line up with the prefix.
- *
- * If word_boundary is TRUE, then attempt to only break lines on
- * boundaries between words.
- *
- * XXX Note that we don't use nvalloc() or any of the other wrapper
- * functions from here, so that this function doesn't require any
- * non-c library symbols (so that it can be called from dlopen()'ed
- * user interfaces.
- */
-
-TextRows *nv_format_text_rows(const char *prefix, const char *str,
-                              int width, int word_boundary)
-{
-    int len, prefix_len, z, w, i;
-    char *line, *buf, *local_prefix, *a, *b, *c;
-    TextRows *t;
-    
-    /* initialize the TextRows structure */
-
-    t = (TextRows *) malloc(sizeof(TextRows));
-    t->t = NULL;
-    t->n = 0;
-    t->m = 0;
-
-    if (!str) return t;
-
-    buf = strdup(str);
-
-    z = strlen(buf); /* length of entire string */
-    a = buf;         /* pointer to the start of the string */
-
-    /* initialize the prefix fields */
-
-    if (prefix) {
-        prefix_len = strlen(prefix);
-        local_prefix = nvstrdup(prefix);
-    } else {
-        prefix_len = 0;
-        local_prefix = NULL;
-    }
-
-    /* adjust the max width for any prefix */
-
-    w = width - prefix_len;
-
-    do {
-        /*
-         * if the string will fit on one line, point b to the end of the
-         * string
-         */
-        
-        if (z < w) b = a + z;
-
-        /* 
-         * if the string won't fit on one line, move b to where the
-         * end of the line should be, and then move b back until we
-         * find a space; if we don't find a space before we back b all
-         * the way up to a, just assign b to where the line should end.
-         */
-        
-        else {
-            b = a + w;
-            
-            if (word_boundary) {
-                while ((b >= a) && (!isspace(*b))) b--;
-                if (b <= a) b = a + w;
-            }
-        }
-
-        /* look for any newline inbetween a and b, and move b to it */
-        
-        for (c = a; c < b; c++) if (*c == '\n') { b = c; break; }
-        
-        /*
-         * copy the string that starts at a and ends at b, prepending
-         * with a prefix, if present
-         */
-
-        len = b-a;
-        len += prefix_len;
-        line = (char *) malloc(len+1);
-        if (local_prefix) strncpy(line, local_prefix, prefix_len);
-        strncpy(line + prefix_len, a, len - prefix_len);
-        line[len] = '\0';
-        
-        /* append the new line to the array of text rows */
-
-        t->t = (char **) realloc(t->t, sizeof(char *) * (t->n + 1));
-        t->t[t->n] = line;
-        t->n++;
-        
-        if (t->m < len) t->m = len;
-
-        /*
-         * adjust the length of the string and move the pointer to the
-         * beginning of the new line
-         */
-        
-        z -= (b - a + 1);
-        a = b + 1;
-
-        /* move to the first non whitespace character (excluding newlines) */
-        
-        if (word_boundary && isspace(*b)) {
-            while ((z) && (isspace(*a)) && (*a != '\n')) a++, z--;
-        } else {
-            if (!isspace(*b)) z++, a--;
-        }
-        
-        if (local_prefix) {
-            for (i = 0; i < prefix_len; i++) local_prefix[i] = ' ';
-        }
-        
-    } while (z > 0);
-
-    if (local_prefix) free(local_prefix);
-    free(buf);
-    
-    return t;
-
-} /* nv_format_text_rows() */
-
-
-
-/*
- * nv_free_text_rows() - free the TextRows data structure allocated by
- * nv_format_text_rows()
- */
-
-void nv_free_text_rows(TextRows *t)
-{
-    int i;
-    
-    if (!t) return;
-    for (i = 0; i < t->n; i++) free(t->t[i]);
-    if (t->t) free(t->t);
-    free(t);
-
-} /* nv_free_text_rows() */
