@@ -22,7 +22,7 @@
  *      Boston, MA 02111-1307, USA
  *
  *
- * nv_installer.h
+ * nvidia-installer.h
  */
 
 #ifndef __NVIDIA_INSTALLER_H__
@@ -141,7 +141,6 @@ typedef struct __options {
     int no_x_check;
     int no_nvidia_xconfig_question;
     int run_distro_scripts;
-    int no_nouveau_check;
 
     char *opengl_prefix;
     char *opengl_libdir;
@@ -324,7 +323,12 @@ typedef struct {
 #define FILE_TYPE_CUDA_HEADER                   0x0000000000400000ULL
 #define FILE_TYPE_CUDA_LIB                      0x0000000000800000ULL
 #define FILE_TYPE_CUDA_SYMLINK                  0x0000000001000000ULL
+#define FILE_TYPE_VDPAU_LIB                     0x0000000002000000ULL
+#define FILE_TYPE_VDPAU_SYMLINK                 0x0000000004000000ULL
+#define FILE_TYPE_VDPAU_HEADER                  0x0000000008000000ULL
 #define FILE_TYPE_UTILITY_BIN_SYMLINK           0x0000000010000000ULL
+#define FILE_TYPE_CUDA_ICD                      0x0000000020000000ULL
+
 
 /* file class: this is used to distinguish OpenGL libraries */
 
@@ -349,23 +353,31 @@ typedef struct {
                                     FILE_TYPE_MANPAGE            | \
                                     FILE_TYPE_OPENGL_HEADER      | \
                                     FILE_TYPE_CUDA_HEADER        | \
+                                    FILE_TYPE_CUDA_ICD           | \
                                     FILE_TYPE_KERNEL_MODULE      | \
                                     FILE_TYPE_INSTALLER_BINARY   | \
                                     FILE_TYPE_UTILITY_BINARY     | \
                                     FILE_TYPE_LIBGL_LA           | \
                                     FILE_TYPE_XMODULE_LIB        | \
-                                    FILE_TYPE_DOT_DESKTOP)
+                                    FILE_TYPE_DOT_DESKTOP        | \
+                                    FILE_TYPE_VDPAU_LIB          | \
+                                    FILE_TYPE_VDPAU_HEADER)
 
 #define FILE_TYPE_HAVE_PATH        (FILE_TYPE_XMODULE_LIB        | \
                                     FILE_TYPE_XMODULE_SYMLINK    | \
                                     FILE_TYPE_XMODULE_NEWSYM     | \
                                     FILE_TYPE_MANPAGE            | \
                                     FILE_TYPE_OPENGL_HEADER      | \
+                                    FILE_TYPE_CUDA_LIB           | \
+                                    FILE_TYPE_CUDA_SYMLINK       | \
                                     FILE_TYPE_CUDA_HEADER        | \
                                     FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_TLS_SYMLINK        | \
                                     FILE_TYPE_DOT_DESKTOP        | \
-                                    FILE_TYPE_DOCUMENTATION)
+                                    FILE_TYPE_DOCUMENTATION      | \
+                                    FILE_TYPE_VDPAU_SYMLINK      | \
+                                    FILE_TYPE_VDPAU_LIB          | \
+                                    FILE_TYPE_VDPAU_HEADER)
 
 #define FILE_TYPE_HAVE_ARCH        (FILE_TYPE_OPENGL_LIB         | \
                                     FILE_TYPE_CUDA_LIB           | \
@@ -373,7 +385,9 @@ typedef struct {
                                     FILE_TYPE_CUDA_SYMLINK       | \
                                     FILE_TYPE_LIBGL_LA           | \
                                     FILE_TYPE_TLS_LIB            | \
-                                    FILE_TYPE_TLS_SYMLINK)
+                                    FILE_TYPE_TLS_SYMLINK        | \
+                                    FILE_TYPE_VDPAU_SYMLINK      | \
+                                    FILE_TYPE_VDPAU_LIB)
 
 #define FILE_TYPE_HAVE_CLASS       (FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_TLS_SYMLINK)
@@ -384,7 +398,8 @@ typedef struct {
                                     FILE_TYPE_TLS_SYMLINK        | \
                                     FILE_TYPE_XMODULE_SYMLINK    | \
                                     FILE_TYPE_UTILITY_LIB_SYMLINK| \
-                                    FILE_TYPE_UTILITY_BIN_SYMLINK)
+                                    FILE_TYPE_UTILITY_BIN_SYMLINK| \
+                                    FILE_TYPE_VDPAU_SYMLINK)
 
 #define FILE_TYPE_NEWSYM           (FILE_TYPE_XMODULE_NEWSYM)
 
@@ -399,7 +414,8 @@ typedef struct {
                                     FILE_TYPE_XLIB_SHARED_LIB    | \
                                     FILE_TYPE_TLS_LIB            | \
                                     FILE_TYPE_XMODULE_SHARED_LIB | \
-                                    FILE_TYPE_UTILITY_LIB)
+                                    FILE_TYPE_UTILITY_LIB        | \
+                                    FILE_TYPE_VDPAU_LIB)
 
 #define TLS_LIB_TYPE_FORCED         0x0001
 #define TLS_LIB_NEW_TLS             0x0002
@@ -425,7 +441,6 @@ typedef struct {
  * command line.
  */
 #define DEFAULT_OPENGL_PREFIX           "/usr"
-#define DEFAULT_CUDA_PREFEIX            "/usr"
 #define DEFAULT_X_PREFIX                "/usr/X11R6"
 #define DEFAULT_UTILITY_PREFIX          "/usr"
 #define DEFAULT_DOCUMENTATION_PREFIX    "/usr"
@@ -488,11 +503,20 @@ typedef struct {
 #define NV_BULLET_STR "-> "
 #define NV_CMD_OUT_PREFIX "   "
 
+/*
+ * The OpenCL ICD Loader will look for the NVIDIA ICD
+ * in /etc/OpenCL/vendors
+ */
+#define DEFAULT_CUDA_ICD_PREFIX          "/etc"
+#define DEFAULT_CUDA_ICD_DIR             "OpenCL/vendors"
+
 /* useful macros */
 
 #define NV_MIN(x,y) ((x) < (y) ? (x) : (y))
 #define NV_MAX(x,y) ((x) > (y) ? (x) : (y))
 
+#define TAB "  "
+#define BIGTAB "      "
 
 /* prototypes of functions used throughout the installer */
 
