@@ -221,28 +221,26 @@ int report_latest_driver_version(Options *op)
  */
 
 char *append_update_arguments(char *s, int c, const char *arg,
-                              const NVGetoptOption *options)
+                              struct option l[])
 {
     char *t;
     int i = 0;
 
-    if (!s) {
-        s = nvstrcat(" ", NULL);
-    }
+    if (!s) s = nvstrcat(" ", NULL);
     
     do {
-        if (options[i].val == c) {
-            t = nvstrcat(s, " --", options[i].name, NULL);
+        if (l[i].val == c) {
+            t = nvstrcat(s, " --", l[i].name, NULL);
             nvfree(s);
             s = t;
-            if (options[i].flags & NVGETOPT_HAS_ARGUMENT) {
+            if (l[i].has_arg) {
                 t = nvstrcat(s, "=", arg, NULL);
                 nvfree(s);
                 s = t;
             }
             return (s);
         }
-    } while (options[++i].name);
+    } while (l[++i].name);
     
     return s;
     
